## Adjust Jenkins job path for package
<!--
type: bugfix
scope: all
affected: all
-->

Correct path to Jenkins job providing the package artifact. With CMK-26121 the build package job was split into pre-build, build and sign. This change sets the overall `trigger-cmk-distro-package` as job instead of the `trigger-cmk-distro-package` which would allocate resources longer due to the waittime for the pre-build part. Additionally the package would not be signed.
